from ..base import AdyenServiceBase


class AllowedOriginsMerchantLevelApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AllowedOriginsMerchantLevelApi, self).__init__(client=client)
        self.service = "management"
        self.baseUrl = "https://management-test.adyen.com/v3"

    def create_allowed_origin(self, request, merchantId, apiCredentialId, idempotency_key=None, **kwargs):
        """
        Create an allowed origin
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/apiCredentials/{apiCredentialId}/allowedOrigins"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def delete_allowed_origin(self, merchantId, apiCredentialId, originId, idempotency_key=None, **kwargs):
        """
        Delete an allowed origin
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/apiCredentials/{apiCredentialId}/allowedOrigins/{originId}"
        method = "DELETE"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def get_allowed_origin(self, merchantId, apiCredentialId, originId, idempotency_key=None, **kwargs):
        """
        Get an allowed origin
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/apiCredentials/{apiCredentialId}/allowedOrigins/{originId}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def list_allowed_origins(self, merchantId, apiCredentialId, idempotency_key=None, **kwargs):
        """
        Get a list of allowed origins
        """
        endpoint = self.baseUrl + f"/merchants/{merchantId}/apiCredentials/{apiCredentialId}/allowedOrigins"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase
from .pos_mobile_api import PosMobileApi


class AdyenPosMobileApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenPosMobileApi, self).__init__(client=client)
        self.pos_mobile_api = PosMobileApi(client=client)



from ..base import AdyenServiceBase


class AndroidFilesCompanyLevelApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AndroidFilesCompanyLevelApi, self).__init__(client=client)
        self.service = "management"
        self.baseUrl = "https://management-test.adyen.com/v3"

    def get_android_app(self, companyId, id, idempotency_key=None, **kwargs):
        """
        Get Android app
        """
        endpoint = self.baseUrl + f"/companies/{companyId}/androidApps/{id}"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def list_android_apps(self, companyId, idempotency_key=None, **kwargs):
        """
        Get a list of Android apps
        """
        endpoint = self.baseUrl + f"/companies/{companyId}/androidApps"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def list_android_certificates(self, companyId, idempotency_key=None, **kwargs):
        """
        Get a list of Android certificates
        """
        endpoint = self.baseUrl + f"/companies/{companyId}/androidCertificates"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def reprocess_android_app(self, companyId, id, idempotency_key=None, **kwargs):
        """
        Reprocess Android App
        """
        endpoint = self.baseUrl + f"/companies/{companyId}/androidApps/{id}"
        method = "PATCH"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def upload_android_app(self, companyId, idempotency_key=None, **kwargs):
        """
        Upload Android App
        """
        endpoint = self.baseUrl + f"/companies/{companyId}/androidApps"
        method = "POST"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def upload_android_certificate(self, companyId, idempotency_key=None, **kwargs):
        """
        Upload Android Certificate
        """
        endpoint = self.baseUrl + f"/companies/{companyId}/androidCertificates"
        method = "POST"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase


class ManageCardPINApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(ManageCardPINApi, self).__init__(client=client)
        self.service = "balancePlatform"
        self.baseUrl = "https://balanceplatform-api-test.adyen.com/bcl/v2"

    def change_card_pin(self, request, idempotency_key=None, **kwargs):
        """
        Change a card PIN
        """
        endpoint = self.baseUrl + f"/pins/change"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)

    def public_key(self, idempotency_key=None, **kwargs):
        """
        Get an RSA public key
        """
        endpoint = self.baseUrl + f"/publicKey"
        method = "GET"
        return self.client.call_adyen_api(None, self.service, method, endpoint, idempotency_key, **kwargs)

    def reveal_card_pin(self, request, idempotency_key=None, **kwargs):
        """
        Reveal a card PIN
        """
        endpoint = self.baseUrl + f"/pins/reveal"
        method = "POST"
        return self.client.call_adyen_api(request, self.service, method, endpoint, idempotency_key, **kwargs)




from ..base import AdyenServiceBase
from .data_protection_api import DataProtectionApi


class AdyenDataProtectionApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenDataProtectionApi, self).__init__(client=client)
        self.data_protection_api = DataProtectionApi(client=client)



from ..base import AdyenServiceBase
from .recurring_api import RecurringApi


class AdyenRecurringApi(AdyenServiceBase):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, client=None):
        super(AdyenRecurringApi, self).__init__(client=client)
        self.recurring_api = RecurringApi(client=client)
